aboutsummaryrefslogtreecommitdiff
path: root/src/mlia/cli
diff options
context:
space:
mode:
authorBenjamin Klimczak <benjamin.klimczak@arm.com>2022-06-28 10:29:35 +0100
committerBenjamin Klimczak <benjamin.klimczak@arm.com>2022-07-08 10:57:19 +0100
commitc9b4089b3037b5943565d76242d3016b8776f8d2 (patch)
tree3de24f79dedf0f26f492a7fa1562bf684e13a055 /src/mlia/cli
parentba2c7fcccf37e8c81946f0776714c64f73191787 (diff)
downloadmlia-c9b4089b3037b5943565d76242d3016b8776f8d2.tar.gz
MLIA-546 Merge AIET into MLIA
Merge the deprecated AIET interface for backend execution into MLIA: - Execute backends directly (without subprocess and the aiet CLI) - Fix issues with the unit tests - Remove src/aiet and tests/aiet - Re-factor code to replace 'aiet' with 'backend' - Adapt and improve unit tests after re-factoring - Remove dependencies that are not needed anymore (click and cloup) Change-Id: I450734c6a3f705ba9afde41862b29e797e511f7c
Diffstat (limited to 'src/mlia/cli')
-rw-r--r--src/mlia/cli/config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mlia/cli/config.py b/src/mlia/cli/config.py
index 838b051..a673230 100644
--- a/src/mlia/cli/config.py
+++ b/src/mlia/cli/config.py
@@ -5,7 +5,7 @@ import logging
from functools import lru_cache
from typing import List
-import mlia.tools.aiet_wrapper as aiet
+import mlia.backend.manager as backend_manager
from mlia.tools.metadata.common import DefaultInstallationManager
from mlia.tools.metadata.common import InstallationManager
from mlia.tools.metadata.corstone import get_corstone_installations
@@ -25,12 +25,12 @@ def get_available_backends() -> List[str]:
"""Return list of the available backends."""
available_backends = ["Vela"]
# Add backends using AIET
manager = get_installation_manager()
available_backends.extend(
(
backend
- for backend in aiet.supported_backends()
+ for backend in backend_manager.supported_backends()
if manager.backend_installed(backend)
)
)
@@ -25,12 +25,12 @@ def get_available_backends() -> List[str]:
"""Return list of the available backends."""
available_backends = ["Vela"]
- # Add backends using AIET
+ # Add backends using backend manager
manager = get_installation_manager()
available_backends.extend(